Service class

Constructors

Service(String token)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordEvent(Offset position, BuildContext context, bool debugMode, double scrooll, String path, Map<String, String>? properties, String? session) Future<void>
sendPackage(List<Map<String, dynamic>> clicksPackage, String? session) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited